Models — django-asana 1.1.1 documentation

# Models

class `djasana.models.` `Attachment`(*args, **kwargs)

  A remote file.

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `BaseModel`(*args, **kwargs)

  An abstract base class for Asana models.

class `djasana.models.` `Hearted`(*args, **kwargs)

  A record that a user has liked a thing.

class `djasana.models.` `Project`(*args, **kwargs)

  An Asana project in a workspace having a collection of tasks.

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`
  `asana_url`()

    Returns the absolute url for this project at Asana.

class `djasana.models.` `Story`(*args, **kwargs)

  The log of a change to an Asana object.

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `SyncToken`(*args, **kwargs)

  The most recent sync token received from Asana for the project

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `Tag`(id, remote_id, name)
  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `Task`(*args, **kwargs)

  An Asana task; something that needs doing.

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`
  `add_comment`(text)

    Adds a comment in Asana for this task.

  `asana_url`(project=None)

    Returns the absolute url for this task at Asana.

  `delete_from_asana`(*args, **kwargs)

    Deletes this task from Asana and then deletes this model instance.

  `refresh_from_asana`()

    Updates this task from Asana.

  `sync_to_asana`(fields=None)

    Updates Asana to match values from this task.

class `djasana.models.` `Team`(id, remote_id, name, organization_id, organization_name)
  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `User`(*args, **kwargs)

  An Asana user.

  Note this is not related to a django User (although you can establish a relationship yourself).

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `Webhook`(*args, **kwargs)

  A secret negotiated with Asana for keeping a project synchronized.

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

class `djasana.models.` `Workspace`(*args, **kwargs)

  An object for grouping projects

  exception `DoesNotExist`
  exception `MultipleObjectsReturned`

`djasana.models.` `get_next_color`()

  Returns the next color choice.

  For assigning to new Asana projects. Cache where we are in the list.